# Installation
```bash
# using `-e` you can change anything in dpvs folder and it will take effect immediately
pip install -e .
```


# How to run

first you should define `PROJECT_ROOT` environmental variable in a `.env` file that is located in the same directory with your script or your jupyter notebook

```sh
python main.py
```


# ChangeLog

~~__pre_init__ ==> pre_initialize~~
